@@ -18,7 +18,7 @@
 from box import Box, BoxList
 from requests import Response
 
-from zscaler.utils import Iterator, snake_to_camel
+from zscaler.utils import snake_to_camel
 from zscaler.zia import ZIAClient
 
 
@@ -43,8 +43,6 @@ class LocationsAPI:
                 Specifies the page size. The default size is 100, but the maximum size is 1000.
             **search (str, optional):
                 The search string used to partially match against a location's name and port attributes.
-            **xff_enabled (bool, optional):
-                Filter based on whether the Enforce XFF Forwarding setting is enabled or disabled for a location.
 
         Returns:
             :obj:`BoxList`: List of configured locations.
@@ -66,7 +64,8 @@ class LocationsAPI:
             ...    print(location)
 
         """
-        return BoxList(Iterator(self.rest, "locations", **kwargs))
+        list, _ = self.rest.get_paginated_data(path="/locations", **kwargs)
+        return list
 
     def get_location(self, location_id: str = None, location_name: str = None) -> Box:
         """
@@ -188,6 +187,7 @@ class LocationsAPI:
             description (str, optional):
                 Additional notes or information regarding the location or sub-location. The description cannot
                 exceed 1024 characters.
+            static_location_groups (list): IDs for static location groups.
 
         Returns:
             :obj:`Box`: The newly created location resource record
@@ -258,14 +258,8 @@ class LocationsAPI:
             ...    pprint(sub_location)
 
         """
-        return BoxList(
-            Iterator(
-                self.rest,
-                f"locations/{location_id}/sublocations",
-                max_pages=1,
-                **kwargs,
-            )
-        )
+        list, _ = self.rest.get_paginated_data(path=f"/locations/{location_id}/sublocations", **kwargs)
+        return list
 
     def list_locations_lite(self, **kwargs) -> BoxList:
         """
@@ -305,7 +299,8 @@ class LocationsAPI:
             ...    print(location)
 
         """
-        return BoxList(Iterator(self.rest, "locations/lite", **kwargs))
+        list, _ = self.rest.get_paginated_data(path="/locations/lite", **kwargs)
+        return list
 
     def update_location(self, location_id: str, **kwargs) -> Box:
         """
@@ -462,6 +457,27 @@ class LocationsAPI:
         """
         return self.rest.delete(f"locations/{location_id}").status_code
 
+    def bulk_delete_locations(self, location_ids: list, **kwargs) -> int:
+        """
+        Deletes all specified Location Management from ZIA.
+
+        Args:
+            location_ids (list): The list of unique ids for the ZIA Locations that will be deleted.
+
+        Returns:
+            :obj:`int`: The status code for the operation.
+
+        Examples:
+            >>> zia.locations.bulk_delete_locations(['111111', '222222', '333333'])
+
+        """
+        payload = {"ids": location_ids}
+        response = self.rest.post("locations/bulkDelete", json=payload).status_code
+        if isinstance(response, Response):
+            status_code = response.status_code
+            raise Exception(f"API call failed with status {status_code}: {response.json()}")
+        return response
+
     def list_location_groups(self, **kwargs) -> BoxList:
         """
         Return a list of location groups in ZIA.
@@ -470,7 +486,11 @@ class LocationsAPI:
             **kwargs: Optional keyword args.
 
         Keyword Args:
-            groupType (str): The location group's type (i.e., Static or Dynamic).
+            name (str): The location group's name.
+            comments (str): Additional comments or information about the location group.
+            groupType (str): The location group's type (i.e., STATIC_GROUP or DYNAMIC_GROUP).
+            location_id (int): The unique identifier for a location within a location group.
+            last_mod_user (str): The admin who modified the location group last.
 
         Returns:
             :obj:`BoxList`: A list of location group resource records.
@@ -479,8 +499,8 @@ class LocationsAPI:
             Get a list of all configured location groups:
             >>> location = zia.locations.list_location_groups()
         """
-        payload = {snake_to_camel(key): value for key, value in kwargs.items()}
-        return self.rest.get("locations/groups", json=payload)
+        list, _ = self.rest.get_paginated_data(path="/locations/groups", **kwargs)
+        return list
 
     def get_location_group_by_id(self, group_id: int) -> Box:
         """
@@ -498,26 +518,7 @@ class LocationsAPI:
         """
         return self.rest.get(f"locations/groups/{group_id}")
 
-    def get_location_group_by_name(self, group_name: str, page: int = 1, page_size: int = 100) -> Box:
-        """
-        Return a specific location group by its name in ZIA.
-
-        Args:
-            group_name (str): The name of the location group.
-            page (int, optional): Page number to retrieve. Defaults to 1.
-            page_size (int, optional): Number of records per page. Defaults to 100.
-
-        Returns:
-            :obj:`Box`: A location group resource record.
-
-        Examples:
-            Get a specific location group by its name:
-            >>> location = zia.locations.get_location_group_by_name("Unassigned Locations")
-        """
-        params = {"page": page, "pageSize": page_size, "search": group_name}
-        return self.rest.get("locations/groups", json=params)
-
-    def list_location_groups_lite(self, **kwargs) -> BoxList:
+    def list_location_groups_lite(self, page: int = 1, page_size: int = 100) -> BoxList:
         """
         Returns a list of location groups (lite version) by their ID where only name and ID is returned in ZIA.
 
@@ -525,7 +526,7 @@ class LocationsAPI:
             **kwargs: Optional keyword args.
 
         Keyword Args:
-            groupType (str): The location group's type (i.e., Static or Dynamic).
+            groupType (str): The location group's type (i.e., STATIC_GROUP or DYNAMIC_GROUP).
 
         Returns:
             :obj:`BoxList`: A list of location group resource records.
@@ -534,8 +535,8 @@ class LocationsAPI:
             Get a list of all configured location groups:
             >>> location = zia.locations.list_location_groups_lite()
         """
-        payload = {snake_to_camel(key): value for key, value in kwargs.items()}
-        return self.rest.get("locations/groups/lite", json=payload)
+        params = {"page": page, "pageSize": page_size}
+        return self.rest.get("locations/groups/lite", params=params)
 
     def get_location_group_lite_by_id(self, group_id: int) -> Box:
         """
@@ -553,24 +554,37 @@ class LocationsAPI:
         """
         return self.rest.get(f"locations/groups/lite/{group_id}")
 
-    def get_location_group_lite_by_name(self, group_name: str, page: int = 1, page_size: int = 100) -> BoxList:
+    def list_location_groups_count(self, **kwargs) -> BoxList:
         """
-        Return specific location groups (lite version) by their name where only name and ID is returned in ZIA.
+        Returns a list of location groups for your organization.
 
         Args:
-            group_name (str): The name of the location group.
-            page (int, optional): Page number to retrieve. Defaults to 1.
-            page_size (int, optional): Number of records per page. Defaults to 100.
+            **kwargs: Optional keyword args.
+
+        Keyword Args:
+            group_type (str): The location group's type (i.e., STATIC_GROUP or DYNAMIC_GROUP).
+            last_mod_user (str): The admin who modified the location group last.
+            version (int): The version parameter is for Zscaler internal use only. Used by the service for backup operations.
+            name (str): The location group's name.
+            comments (str): Additional comments or information about the location group.
+            location_id (int): The unique identifier for a location within a location group.
 
         Returns:
-            :obj:`BoxList`: A list of location group resource records with only ID and name.
+            :obj:`BoxList`: A list of location group resource records.
 
         Examples:
-            Get specific location groups (lite version) by name:
-            >>> locations = zia.locations.get_location_group_lite_by_name("Unassigned Locations")
+            Gets the list of location groups for your organization:
+            >>> location = zia.locations.list_location_groups_count(group_type='STATIC_GROUP', name='Corporate')
         """
-        params = {"page": page, "pageSize": page_size, "search": group_name}
-        return self.rest.get("locations/groups/lite", json=params)
+        params = {}
+        optional_params = ["group_type", "last_mod_user", "version", "name", "comments", "location_id"]
+
+        for key in optional_params:
+            if key in kwargs:
+                params[key] = kwargs[key]
+
+        response = self.rest.get("locations/groups/count", params=params)
+        return int(response.text)
 
     def list_region_geo_coordinates(self, latitude: int, longitude: int) -> Box:
         """
@@ -640,6 +654,5 @@ class LocationsAPI:
             returned. Ensure you narrow your search result as much as possible to avoid this.
 
         """
-        return BoxList(Iterator(self.rest, "region/search", **kwargs))
-        # data, _ = self.rest.get_paginated_data(path="region/search", params=kwargs)
-        # return BoxList([Box(city) for city in data])
+        list, _ = self.rest.get_paginated_data(path="/region/search", **kwargs)
+        return list
